#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct 26 11:30:44 2021

@author: ricardofaria
"""


import numpy as np
from netCDF4 import Dataset
import glob
from dir import dir
from grid_interp import interpolate_2d_grid


input_files = dir("..", pattern_file=".csv")
output_files = []

for string in input_files:
    output_file = string.replace(".csv", ".nc")
    output_files.append(output_file)
    

roms_path = sorted(glob.glob('../Resource/meteo_oceanic_data/tmy/Porto_Santo_201112_roms.nc'))

roms_grid = Dataset(roms_path[0])
lat_roms = roms_grid.variables['Latitude'][:]
lon_roms = roms_grid.variables['Longitude'][:]

mask = roms_grid.variables['salt'][0,0,:]
mask = np.ma.masked_where(mask == 1e+37, mask)
mask = np.ma.getmask(mask)

roms_grid.close()


for f in output_files:
    
    print('Opening file ', f)
    grid = Dataset(f, 'r+')
    
    lat_grid = grid.variables['latitude'][:]
    lon_grid = grid.variables['longitude'][:]
    
    grid_list_vars = grid.variables.keys()
    
    grid.createDimension('lon_rgd', len(lon_roms))
    grid.createDimension('lat_rgd', len(lat_roms))
    nc_longitude = grid.createVariable('longitude_regrid',  np.float32, 'lon_rgd')
    nc_latitude = grid.createVariable('latitude_regrid',  np.float32, 'lat_rgd')
    nc_longitude.units = 'degree_east'
    nc_latitude.units = 'degree_north'
    nc_longitude[:] = lon_roms.data
    nc_latitude[:] = lat_roms.data
    
    for v in list(grid_list_vars):
        
        if 'crs' == v or 'longitude' == v or 'latitude' == v or 'height' == v or 'Time' == v or 'latitude_regrid' == v or 'longitude_regrid' == v :
            print('Skip ', v)
        else :
            print('Work on ', v)
            # interpolate data from old  grid to the new roms grid
            var = grid.variables[v][:]
            var = var.filled(0)
            # var_str = v+'_rgd'
            if len(var.shape) == 2:
                nc_file_final_var = grid.createVariable(v+'_regrid', np.float32, ('lat_rgd', 'lon_rgd'), zlib=True)
                nc_file_final_var[:] = interpolate_2d_grid(var, mask, lon_grid, lat_grid, lon_roms, lat_roms)
    
    grid.close()
